@@ -5,6 +5,10 @@
 #include "platutil.h"
 
 #include <QDesktopServices>
+#include <QNetworkAccessManager>
+#include <QNetworkRequest>
+#include <QNetworkReply>
+#include <QLabel>
 
 CommentView::CommentView(RedditSession* ses, QWidget *parent) :
     QMainWindow(parent),
@@ -16,6 +20,8 @@ CommentView::CommentView(RedditSession* ses, QWidget *parent) :
     connect(m_ses, SIGNAL(commentsAvailable()), this, SLOT(populate()));
     menuBar()->addAction(tr("Open link"), this, SLOT(openLink()));
     menuBar()->addAction(tr("Full"), this, SLOT(openBrowser()));
+    connect(ui->m_thumbnailButton, SIGNAL(clicked()), this, SLOT(openLink()));
+    ui->m_thumbnailButton->setFlat(true);
 
 }
 
@@ -37,10 +43,18 @@ void CommentView::openLink()
 
 void CommentView::setEntry(const RedditEntry &e)
 {
-    m_entry = e;
+    m_entry = e;    
     m_ses->fetchComments(e.permalink);
     setWindowTitle(e.desc);
     PlatUtil::toggleBusy(this, true);
+    if (m_entry.thumbnail.length()) {
+        QNetworkRequest req(m_entry.thumbnail);
+        QNetworkReply* reply = m_ses->m_net->get(req);
+        connect(reply, SIGNAL(finished()), this, SLOT(thumbnailFetched()));
+        ui->m_thumbnailButton->setVisible(true);
+    } else {
+        ui->m_thumbnailButton->setVisible(false);
+    }
 
 }
 
@@ -63,6 +77,20 @@ void CommentView::populate()
 
     QString coms = m_ses->comments().join("<hr/>");
     QString all = "<p>"+coms+ "</p>";
-
     ui->textBrowser->setHtml(all);
 }
+
+void CommentView::thumbnailFetched()
+{
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
+    if (!reply)
+        return;
+
+    QImage* img = new QImage;
+    img->load(reply, NULL);
+    QIcon icon;
+    icon.addPixmap(QPixmap::fromImage(*img));
+    ui->m_thumbnailButton->setIcon(icon);
+    delete img;
+
+}
